==> jc-1.4.0.tar.gz: soot/jimple/internal/IdentityRefBox.h <==
// public class soot.jimple.internal.IdentityRefBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class da7c18ad1f3a85ab soot_jimple_internal_IdentityRefBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_AbstractValueBox

#include "soot/AbstractValueBox.h"

#ifndef _JC_soot_jimple_internal_IdentityRefBox_H_
#define _JC_soot_jimple_internal_IdentityRefBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_IdentityRefBox$sub_refs	_jc_soot_jimple_internal_IdentityRefBox$sub_refs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs	_jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$refs	_jc_soot_jimple_internal_IdentityRefBox$refs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$nonrefs	_jc_soot_jimple_internal_IdentityRefBox$nonrefs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$object	_jc_soot_jimple_internal_IdentityRefBox$object;

typedef const struct _jc_soot_jimple_internal_IdentityRefBox$vmethods	_jc_soot_jimple_internal_IdentityRefBox$vmethods;
typedef const struct _jc_soot_jimple_internal_IdentityRefBox$vtable	_jc_soot_jimple_internal_IdentityRefBox$vtable;
typedef const struct _jc_soot_jimple_internal_IdentityRefBox$vtype	_jc_soot_jimple_internal_IdentityRefBox$vtype;

// Constructors
extern void _jc_soot_jimple_internal_IdentityRefBox$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_jimple_internal_IdentityRefBox$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_internal_IdentityRefBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_jimple_internal_IdentityRefBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_IdentityRefBox$method_info$canContainValue$dd22978795c5cdfb;

// Virtual methods structure
struct _jc_soot_jimple_internal_IdentityRefBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_jimple_internal_IdentityRefBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_IdentityRefBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_jimple_internal_IdentityRefBox$vmethods	soot_jimple_internal_IdentityRefBox;
};

// Vtype
struct _jc_soot_jimple_internal_IdentityRefBox$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_IdentityRefBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_IdentityRefBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_IdentityRefBox$refs {
    _jc_soot_jimple_internal_IdentityRefBox$sub_refs	soot_jimple_internal_IdentityRefBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_IdentityRefBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs	soot_jimple_internal_IdentityRefBox;
};

// Object instance structure
struct _jc_soot_jimple_internal_IdentityRefBox$object {
	_jc_soot_jimple_internal_IdentityRefBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_IdentityRefBox$vtype	*vtype;
	_jc_soot_jimple_internal_IdentityRefBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_IdentityRefBox$vtype _jc_soot_jimple_internal_IdentityRefBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_IdentityRefBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_IdentityRefBox$class_object;

#endif	/* _JC_soot_jimple_internal_IdentityRefBox_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/IdentityRefBox.h <==
// public class soot.jimple.internal.IdentityRefBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class da7c18ad1f3a85ab soot_jimple_internal_IdentityRefBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_AbstractValueBox

#include "soot/AbstractValueBox.h"

#ifndef _JC_soot_jimple_internal_IdentityRefBox_H_
#define _JC_soot_jimple_internal_IdentityRefBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_IdentityRefBox$sub_refs	_jc_soot_jimple_internal_IdentityRefBox$sub_refs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs	_jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$refs	_jc_soot_jimple_internal_IdentityRefBox$refs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$nonrefs	_jc_soot_jimple_internal_IdentityRefBox$nonrefs;
typedef struct _jc_soot_jimple_internal_IdentityRefBox$object	_jc_soot_jimple_internal_IdentityRefBox$object;

typedef const struct _jc_soot_jimple_internal_IdentityRefBox$vmethods	_jc_soot_jimple_internal_IdentityRefBox$vmethods;
typedef const struct _jc_soot_jimple_internal_IdentityRefBox$vtable	_jc_soot_jimple_internal_IdentityRefBox$vtable;
typedef const struct _jc_soot_jimple_internal_IdentityRefBox$vtype	_jc_soot_jimple_internal_IdentityRefBox$vtype;

// Constructors
extern void _jc_soot_jimple_internal_IdentityRefBox$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_jimple_internal_IdentityRefBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_internal_IdentityRefBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_jimple_internal_IdentityRefBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_IdentityRefBox$method_info$canContainValue$dd22978795c5cdfb;

// Virtual methods structure
struct _jc_soot_jimple_internal_IdentityRefBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_jimple_internal_IdentityRefBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_IdentityRefBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_jimple_internal_IdentityRefBox$vmethods	soot_jimple_internal_IdentityRefBox;
};

// Vtype
struct _jc_soot_jimple_internal_IdentityRefBox$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_IdentityRefBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_IdentityRefBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_IdentityRefBox$refs {
    _jc_soot_jimple_internal_IdentityRefBox$sub_refs	soot_jimple_internal_IdentityRefBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_IdentityRefBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_jimple_internal_IdentityRefBox$sub_nonrefs	soot_jimple_internal_IdentityRefBox;
};

// Object instance structure
struct _jc_soot_jimple_internal_IdentityRefBox$object {
	_jc_soot_jimple_internal_IdentityRefBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_IdentityRefBox$vtype	*vtype;
	_jc_soot_jimple_internal_IdentityRefBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_IdentityRefBox$vtype _jc_soot_jimple_internal_IdentityRefBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_IdentityRefBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_IdentityRefBox$class_object;

#endif	/* _JC_soot_jimple_internal_IdentityRefBox_H_ */
